# Operator - Provisioning PGP Keypair 

The initial setup requires the provisioner and operator to do all of these in a continuous session ensuring dual custody. Ensure that all participants are familiar with the sub-processes so that the ceremony can be completed in one working day.

## Requirements

* 3 individuals in order to have the flexibility for washroom breaks, fetching food and drinks etc. 

    * 1 Operator

    * 1 Provisioner

    * 1 person to witness, but should be familiar with the process

* [AirgapOS SD Card](./provision-airgapos.md)

* [Tamper Proofing Equipment](./provision-tamper-proofing-equipment.md)

* [Smart Cards](../../../../component-documents/hardware-models.md#smart-cards)

    * 2 per PGP keypair (more than 2 smart cards can be provisioned per keypair if desired, for redundancy)

* SD Cards: [Provisioning Guide](./provision-sd-card.md)

    * 3 per PGP keypair (for backups)

    * 2 additional SD cards for Keychain SD cards

* Designated [facility](./provision-facility.md)

* Sealable plastic bag: {{ #include ../../../../component-documents/hardware-models.md:sealable-plastic-bags }}
    * For hardware procurement

* Tin can + lighter (HACK, this goes away when we fix keyfork)

    * This is used for burning materials produced during the ceremony which contain sensitive information

## Procedure

### Procure Computer (AirgapOS Compatible) 

#### Compatible Hardware

{{ #include ../../hardware.md:computer-models }}

#### Procedure

{{ #include ../../../../component-documents/hardware-procurement-and-chain-of-custody.md:steps }}

    * In this case, wait until later steps where further instructions on how to tamper proof the computer

### Ceremony 

1. Enter the designated facility with all participants and required equipment

1. Lock access to the facility - there should be no inflow of new people during the ceremony if avoidable.

1. Remove all unnecessary parts from the laptop before using it to reduce side-channel and data remnance attack risk: radio cards, speakers, microphones, storage drive. 
    * While this is not required for Level 2 security, it MAY be done in order to improve security of the system.

1. Boot AirgapOS from verified SD card

1. Check AirgapOS hashes when it's booted

#### Generating PGP Keys and Seeding Cards

Repeat these steps for each keypair:

{{ #include ../../../../component-documents/openpgp-setup.md:steps-keyfork}}

1. Do not turn off the computer as you will need to use the keys that are loaded for signing in the following section

### Signing Keys

Once the keys are generated, cross-sign all keys, for example:
```    
gpg --clearsign --default-key=<key_id_2> <key_id_1>.asc

gpg --clearsign --default-key=<key_id_1> <key_id_2>.asc
```
1. Store both public keys and both signatures on an SD card and repeat the process so that there are 2 backup SD cards.

    * Label both cards "Keychain <date>"

1. Upload these keys and signatures to the ceremonies repository after the airgapped machine is shut down.

### Air-Gapped Bundle

The following objects should be in the bundle:

* AirgapOS SD Card

* Air-gapped computer

* Keychain SD Card

#### Procedure

{{ #include ../../../../component-documents/tamper-evidence-methods.md:vsbwf-procedure-sealing}}
